@@ -1,31 +1,3 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 """Kedro Telemetry plugin for collecting Kedro usage data."""
 
 import hashlib
@@ -42,10 +14,12 @@ from typing import Any, Dict, List
 import click
 import requests
 import yaml
+from kedro.framework.cli.cli import KedroCLI
 from kedro.framework.cli.hooks import cli_hook_impl
 from kedro.framework.startup import ProjectMetadata
 
 from kedro_telemetry import __version__ as telemetry_version
+from kedro_telemetry.masking import _get_cli_structure, _mask_kedro_cli
 
 HEAP_APPID_PROD = "2388822444"
 
@@ -67,7 +41,14 @@ class KedroTelemetryCLIHooks:
     ):
         """Hook implementation to send command run data to Heap"""
         # pylint: disable=no-self-use
-        main_command = command_args[0] if command_args else "kedro"
+
+        # get KedroCLI and its structure from actual project root
+        cli = KedroCLI(project_path=Path.cwd())
+        cli_struct = _get_cli_structure(cli_obj=cli, get_help=False)
+        masked_command_args = _mask_kedro_cli(
+            cli_struct=cli_struct, command_args=command_args
+        )
+        main_command = masked_command_args[0] if masked_command_args else "kedro"
         if not project_metadata:  # in package mode
             return
 
@@ -94,7 +75,7 @@ class KedroTelemetryCLIHooks:
             )
             return
 
-        properties = _format_user_cli_data(command_args, project_metadata)
+        properties = _format_user_cli_data(masked_command_args, project_metadata)
 
         _send_heap_event(
             event_name=f"Command run: {main_command}",
@@ -112,7 +93,7 @@ class KedroTelemetryCLIHooks:
         )
 
 
-def _format_user_cli_data(command_args, project_metadata):
+def _format_user_cli_data(command_args: List[str], project_metadata: ProjectMetadata):
     """Hash username, format CLI command, system and project data to send to Heap."""
     hashed_username = ""
     try:
@@ -164,12 +145,20 @@ def _send_heap_event(
         "properties": properties or {},
     }
 
-    resp = requests.post(url=HEAP_ENDPOINT, headers=HEAP_HEADERS, data=json.dumps(data))
-    if resp.status_code != 200:
+    try:
+        resp = requests.post(
+            url=HEAP_ENDPOINT, headers=HEAP_HEADERS, data=json.dumps(data)
+        )
+        if resp.status_code != 200:
+            logger.warning(
+                "Failed to send data to Heap. Response code returned: %s, Response reason: %s",
+                resp.status_code,
+                resp.reason,
+            )
+    except requests.exceptions.RequestException as exc:
         logger.warning(
-            "Failed to send data to Heap. Response code returned: %s, Response reason: %s",
-            resp.status_code,
-            resp.reason,
+            "Failed to send data to Heap. Exception of type '%s' was raised.",
+            type(exc).__name__,
         )
 
 
@@ -197,7 +186,7 @@ def _confirm_consent(telemetry_file_path: Path) -> bool:
             "We cannot see nor store information contained in "
             "a Kedro project. \nYou can find out more by reading our "
             "privacy notice: \n"
-            "https://github.com/quantumblacklabs/kedro-telemetry#privacy-notice \n"
+            "https://github.com/kedro-org/kedro-plugins/tree/main/kedro-telemetry#privacy-notice \n"
             "Do you opt into usage analytics? "
         )
         if click.confirm(confirm_msg):
